/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.client.internal.ProjectClient");

dojo.require("com.ibm.rational.report.web.core.client.internal.SessionManager");
dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.team.repository.web.transport.ServiceRequest");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.transport.TeamServerClient");
dojo.require("com.ibm.team.process.web.client.projectarea");

var SessionManager			= com.ibm.rational.report.web.core.client.internal.SessionManager;
var session					= com.ibm.team.repository.web.client.session;
var ServiceRequest 			= com.ibm.team.repository.web.transport.ServiceRequest;
var ServiceResponseHandler 	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var TeamServerClient 		= com.ibm.team.repository.web.transport.TeamServerClient;

/**
 * Manages project REST service calls.
 */
com.ibm.rational.report.web.core.client.internal.ProjectClient = {

	PROCESS_SERVICE_URI: "com.ibm.team.process.internal.common.service.IProcessRestService",

	PROJECT_SERVICE_URI: "com.ibm.rational.project.common.IProjectRestService",

	getProjectAreas: function(responseHandler, args) {
		this._invokeProcessService(responseHandler, "getProjectAreas", args);
	},
	
	getProcessAreasForUser: function(responseHandler, args) {
		this._invokeProcessService(responseHandler, "getProcessAreasForUser", args);
	},	
		
	getProjectMembers: function(responseHandler, args) {
		this._invokeProjectService(responseHandler, "getProjectMembers", args);
	},
	
	postSetProjectMembers: function(responseHandler, args) {
		this._invokeProjectService(responseHandler, "postSetProjectMembers", args);
	},
	
	postAddProjectMember: function(responseHandler, args) {
		this._invokeProjectService(responseHandler, "postAddProjectMember", args);
	},
	
	postAddProjectMembers: function(responseHandler, args) {
		this._invokeProjectService(responseHandler, "postAddProjectMembers", args);
	},
		
	postNewProject: function(responseHandler, args) {
		this._invokeProjectService(responseHandler, "postNewProject", args);
	},

	postUpdateProject: function(responseHandler, args) {
		this._invokeProjectService(responseHandler, "postUpdateProject", args);
	},
	
	postDeleteProject: function(responseHandler, args) {
		this._invokeProjectService(responseHandler, "postDeleteProject", args);
	},
	
	getProcessRoles: function(responseHandler, args) {
		this._invokeProjectService(responseHandler, "getProcessRoles", args);
	},	
	
	/**
	 * Invokes the requested method on the Process REST service.
	 */
	_invokeProcessService: function(responseHandler, method, args) {
		if (arguments.length == 2) {
			var serviceRequest = new com.ibm.team.repository.web.transport.ServiceRequest(
					this.PROCESS_SERVICE_URI,
					method);
		} else {
			serviceRequest = new com.ibm.team.repository.web.transport.ServiceRequest(
					this.PROCESS_SERVICE_URI,
					method,
					args);
		}
		com.ibm.team.repository.web.transport.TeamServerClient.invokeService(
				serviceRequest,
				responseHandler);
		SessionManager.resetTimeOut();
	},
		
	/**
	 * Invokes the requested method on the Project REST service.
	 */
	_invokeProjectService: function(responseHandler, method, args) {
		if (arguments.length == 2) {
			var serviceRequest = new com.ibm.team.repository.web.transport.ServiceRequest(
					this.PROJECT_SERVICE_URI,
					method);
		} else {
			serviceRequest = new com.ibm.team.repository.web.transport.ServiceRequest(
					this.PROJECT_SERVICE_URI,
					method,
					args);
		}
		com.ibm.team.repository.web.transport.TeamServerClient.invokeService(
				serviceRequest,
				responseHandler);
		SessionManager.resetTimeOut();
	}
	
};

})();